@@ -1,17 +1,12 @@
-#[macro_use]
-extern crate error_chain;
-
+use anyhow::{bail, Result};
 use log::debug;
 use parol::analysis::follow_k;
 use parol::analysis::FirstCache;
-use parol::errors::*;
 use parol::generators::generate_terminal_names;
 use parol::{obtain_grammar_config, MAX_K};
 use std::env;
 
-quick_main!(run);
-
-fn run() -> Result<()> {
+fn main() -> Result<()> {
     env_logger::init();
     // $env:RUST_LOG="parol,parol_runtime=off,productivity=debug"
     debug!("env logger started");
