@@ -1,14 +1,9 @@
-#[macro_use]
-extern crate error_chain;
-
+use anyhow::Result;
 use parol::conversions::par::render_par_string;
-use parol::errors::*;
 use parol::obtain_grammar_config;
 use std::env;
 
-quick_main!(run);
-
-fn run() -> Result<()> {
+fn main() -> Result<()> {
     env_logger::init();
     let args: Vec<String> = env::args().collect();
     if args.len() > 1 {
